/*****************************************************************************
 * MDMA_Throughput_Measurements_Core0.c
 *****************************************************************************/

/*****************************************************************************
 * Description: This code tests the peak L2 throughput for write accesses with
 * DMA masters from different SCBs accessing the L2 memory to write the Data.
 * Following DMA are used to do write accesses to L2 memory:
 * -MDMA stream 0  (DMA 21 & 22)
 * -PPI0 DMA (DMA 29)
 * -PPI1 DMA (DMA 33)
 * -PPI2 DMA (DMA 31)
 * -Link Port DMA
 *
 * Data is transfered form L1 to L2 memory
 *****************************************************************************/

#include <ccblkfn.h>
#include "adi_initialize.h"
#include "L2_Max_Throughput.h"
#include <cdefBF609.h>
#include <defBF609.h>
#include "ddr_init.h"
#include "time.h"
#include "stdio.h"
#include "EPPIInit.h"


/* Temporary variable to hold the cycle count and bandwidth information for different DMA block transfers */
volatile clock_t clock_start_mdma;
volatile clock_t clock_stop_mdma;
volatile clock_t cycles_mdma;
float throughput_mdma;

volatile clock_t clock_start_ppi0;
volatile clock_t clock_stop_ppi0;
volatile clock_t cycles_ppi0;
float throughput_ppi0;

volatile clock_t clock_stop_ppi1;
volatile clock_t cycles_ppi1;
float throughput_ppi1;

volatile clock_t clock_stop_ppi2;
volatile clock_t cycles_ppi2;
float throughput_ppi2;

volatile clock_t clock_stop_lp;
volatile clock_t cycles_lp;
float throughput_lp;

/* Total Throughput achieved is stored in this variable */
float throughput_total;

/* Flags to indicate when different DMAs are completed */
int DMA_Done_PPI0=0;
int DMA_Done_PPI1=0;
int DMA_Done_PPI2=0;
int DMA_Done_MDMA=0;
int DMA_Done_LP=0;


/* Source buffer in L1 memory from which DMA channels read the data*/
#pragma align 32
section("L1_data_a") unsigned char ucIntSrcBuff[MAX_SIZE];


#pragma align 32
//section("L1_data_b") unsigned char ucIntDestBuff[MAX_SIZE];

#pragma align 32
//section("L2_sram_bank2") unsigned char ucExtSrcBuff[MAX_SIZE];

/* Destination buffer in L2 memory to which DMA channels write the data*/
#pragma align 32
section("L2_sram_bank2") unsigned char ucExtDestBuff[MAX_SIZE];

/* Function prototypes */
void Measure_Throughput_MDMA_PPI0(unsigned int uiBytes, unsigned int uiSourceDMAConfig, unsigned int uiDestDMAConfig);
void Fill_Buff(unsigned char* ucpBuff, unsigned int uiCount);
void EPPI_init(unsigned int uiEppiID, unsigned int uiBytes);
void EPPI_init1(unsigned int uiEppiID, unsigned int uiBytes);
void EPPI0_Interrupt_Handler (uint32_t iid, void* handlerArg);
void EPPI1_Interrupt_Handler (uint32_t iid, void* handlerArg);
void EPPI2_Interrupt_Handler (uint32_t iid, void* handlerArg);
void MDMA_Interrupt_Handler(uint32_t iid, void* handlerArg);
void LP0_RX_Handler (uint32_t iid, void* handlerArg);
void Init_interrupts(void);

/* Macro to initialize the MDMA stream */
#define MDMA_CONFIG(S_MDMA_CHANNEL,S_CFG, S_ADDRSTART, S_MOD, S_COUNT,D_MDMA_CHANNEL,D_CFG, D_ADDRSTART, D_MOD, D_COUNT)\
		*pREG_DMA##S_MDMA_CHANNEL##_CFG = S_CFG;\
		*pREG_DMA##S_MDMA_CHANNEL##_ADDRSTART = S_ADDRSTART;\
		*pREG_DMA##S_MDMA_CHANNEL##_XCNT = S_COUNT;\
		*pREG_DMA##S_MDMA_CHANNEL##_XMOD = S_MOD;\
		*pREG_DMA##D_MDMA_CHANNEL##_CFG = D_CFG;\
		*pREG_DMA##D_MDMA_CHANNEL##_ADDRSTART = D_ADDRSTART;\
		*pREG_DMA##D_MDMA_CHANNEL##_XCNT = D_COUNT;\
		*pREG_DMA##D_MDMA_CHANNEL##_XMOD = D_MOD;\

/* Macro to disable the MDMA stream */
#define DISABLE_MDMAs(S_MDMA_CHANNEL, D_MDMA_CHANNEL)\
		*pREG_DMA##S_MDMA_CHANNEL##_CFG = 0;\
		*pREG_DMA##D_MDMA_CHANNEL##_CFG = 0;

/* Macro to disable the PPI DMA */
#define DISABLE_PPI_DMA(DMA_CHANNEL)\
		*pREG_DMA##DMA_CHANNEL##_CFG = 0;

/* Macro to initialize the different EPPI DMAs */
#define PDMA_CONFIG(PDMA_CHANNEL,S_CFG, S_ADDRSTART, S_MOD, S_COUNT)\
		*pREG_DMA##PDMA_CHANNEL##_CFG = S_CFG;\
		*pREG_DMA##PDMA_CHANNEL##_ADDRSTART = S_ADDRSTART;\
		*pREG_DMA##PDMA_CHANNEL##_XCNT = S_COUNT;\
		*pREG_DMA##PDMA_CHANNEL##_XMOD = S_MOD;



/**************************************************************************************************************************
	Function name	:   main
    Description		:   Main function
**************************************************************************************************************************/
int main(void)
{
	unsigned int uiBytes = MAX_SIZE;        		/* 16K word transfer size */
	Init_interrupts();								/* Initialize Interrupts */
	Fill_Buff(ucIntSrcBuff, uiBytes);				/* Initialize the source buffer */
	EPPI_init(0, uiBytes );							/* Initialize EPPI0 */
	EPPI_init1(1, uiBytes );						/* Initialize EPPI1 */
	EPPI_init1(2, uiBytes );						/* Initialize EPPI1 */
	Measure_Throughput_MDMA_PPI0(uiBytes, SOURCE_DMA_CFG, DEST_DMA_CFG);	/* Function starts all the DMA and measure the throughput for each DMA */

	return 0;
}

/**************************************************************************************************************************
	Function name	:   Init_interrupts
    Description		:   This function initializes all the interrupts
**************************************************************************************************************************/
void Init_interrupts(void)
{
	*pREG_SEC0_GCTL=ENUM_SEC_GCTL_EN;
	*pREG_SEC0_CCTL0=ENUM_SEC_CCTL_EN;
	adi_int_InstallHandler(INTR_EPPI0_CH0_DMA, EPPI0_Interrupt_Handler, NULL, true);
	adi_int_InstallHandler(INTR_EPPI1_CH0_DMA, EPPI1_Interrupt_Handler, NULL, true);
	adi_int_InstallHandler(INTR_EPPI2_CH0_DMA, EPPI2_Interrupt_Handler, NULL, true);
	adi_int_InstallHandler(INTR_MDMA0_DST, MDMA_Interrupt_Handler, NULL, true);
	adi_int_InstallHandler(INTR_LP0_DMA,LP0_RX_Handler,0,true);
}

/**************************************************************************************************************************
	Function name	:   Fill_Buff
    Description		:   This function initializes the source buffer
**************************************************************************************************************************/
void Fill_Buff(unsigned char* ucpBuff, unsigned int uiCount)
{
	int i=0;
	for(i=0;i<uiCount;i++)
		*ucpBuff++=i;
}

/**************************************************************************************************************************
	Function name	:   Measure_Throughput_MDMA_PPI0
    Description		:   This function initializes and starts all the MDA channels and measures
    					throughput using the cycle count registers of the processor to measure
    					the throughput for the data transfer of 16k bytes
**************************************************************************************************************************/
void Measure_Throughput_MDMA_PPI0(unsigned int uiBytes, unsigned int uiSourceDMAConfig, unsigned int uiDestDMAConfig)
{
	DMA_Done_MDMA = 0;																		/* Reset the DMA done flag initially */
	MDMA_CONFIG(21, uiSourceDMAConfig, ucIntSrcBuff, SOURCE_MSIZE, uiBytes/SOURCE_MSIZE,22,uiDestDMAConfig, ucExtDestBuff , DEST_MSIZE, uiBytes/DEST_MSIZE);
																							/* Initialize the MDMA stream */
	DMA_Done_PPI0 = 0;																		/* Reset the DMA done flag initially */
	PDMA_CONFIG(29, DEST_DMA_CFG, ucExtDestBuff, DEST_MSIZE, uiBytes/DEST_MSIZE);			/* Initialize the PPI0 DMA */
	PDMA_CONFIG(33, DEST_DMA_CFG, ucExtDestBuff, DEST_MSIZE, uiBytes/DEST_MSIZE);			/* Initialize the PPI1 DMA */
	PDMA_CONFIG(31, DEST_DMA_CFG, ucExtDestBuff, DEST_MSIZE, uiBytes/DEST_MSIZE);			/* Initialize the PPI2 DMA */
	*pREG_DMA29_CFG |= 0x1;																	/* Enable PPI0 DMA*/
	*pREG_DMA33_CFG |= 0x1;																	/* Enable PPI1 DMA*/
	*pREG_DMA31_CFG |= 0x1;																	/* Enable PPI2 DMA*/

	Enable_Link_Port_DMA();																	/* Enable Link Port and its DMA */

	*pREG_EPPI0_CTL |= ENUM_EPPI_CTL_EN ;													/* Enable PPI0 */
	*pREG_EPPI1_CTL |= ENUM_EPPI_CTL_EN ;													/* Enable PPI1 */
	*pREG_EPPI2_CTL |= ENUM_EPPI_CTL_EN ;													/* Enable PPI2 */
	clock_start_ppi0 = clock();																/* Start counting the number of clock cycles for PPI transfer */

	*pREG_DMA22_CFG |= 0x1;																	/* Enable MDMA0 */
	*pREG_DMA21_CFG |= 0x1;
	clock_start_mdma = clock();																/* Start counting the number of clock cycles for MDMA transfer */

	while(DMA_Done_MDMA==0||DMA_Done_PPI0==0||DMA_Done_PPI1==0 ||DMA_Done_PPI2==0 || DMA_Done_LP==0/* */);
																							/* Wait till all the DMA transfers are completed */
	cycles_mdma=clock_stop_mdma-clock_start_mdma;											/* Calculate the cycles consumed for each DMA transfer */
	cycles_ppi0=clock_stop_ppi0-clock_start_ppi0;
	cycles_ppi1=clock_stop_ppi1-clock_start_ppi0;
	cycles_ppi2=clock_stop_ppi2-clock_start_ppi0;
	cycles_lp=clock_stop_lp-clock_start_ppi0;

	DISABLE_MDMAs(21,22);																	/* Disable all the DMA channels*/
	DISABLE_PPI_DMA(29);
	DISABLE_PPI_DMA(33);
	DISABLE_PPI_DMA(31);

	throughput_mdma=(float)(uiBytes*CCLK_SPEED/cycles_mdma);								/* Calculate the Throughput for each DMA channel */
	throughput_ppi0=(float)(uiBytes*CCLK_SPEED/cycles_ppi0);
	throughput_ppi1=(float)(uiBytes*CCLK_SPEED/cycles_ppi1);
	throughput_ppi2=(float)(uiBytes*CCLK_SPEED/cycles_ppi2);
	throughput_lp=(float)(uiBytes*CCLK_SPEED/cycles_lp);

	throughput_total=throughput_mdma+throughput_ppi0+throughput_ppi1+throughput_ppi2 +throughput_lp ;
																							/* Calculate the total Throughput achieved for all DMA transfers */
	printf("\n\n No of bytes=%d, No of MDMA cycles=%d, No of PPI0 DMA cycles , No of PPI1 DMA cycles , No of PPI2 DMA cycles",uiBytes,cycles_mdma,cycles_ppi0, cycles_ppi1, cycles_ppi2);
	printf("\n Throughput MDMA=%f MB/s, \n Throughput PPI0=%f MB/s, \n Throughput PPI1=%f MB/s,  \n Throughput PPI2=%f MB/s,  \n Throughput LP=%f MB/s, \n Throughput total=%f\n\n",throughput_mdma, throughput_ppi0, throughput_ppi1, throughput_ppi2,throughput_lp, throughput_total);
}

/**************************************************************************************************************************
	Function name	:   Enable_Link_Port_DMA
    Description		:   This function initializes the Link Port
**************************************************************************************************************************/
void Enable_Link_Port_DMA()
{
	//enable the right mux and fer for GPIO for both link ports, tx and rx
	enable_lp_gpio();

	//enable the lvds switch via IO expander through TWI
	enable_lp_ezkit();

	//enable interrupts. see condition above.
	//enable_interrupts();

	//program link port with transfer direction and interrupt masking
	program_lpDMA(0);

	//program link port with transfer direction and interrupt masking
	program_lpDMA(1);

	//program link port clock for transmitter
	program_lp_clk(1);

	//enable LEN bit of link port transmitter
	enable_lpDMA(0);

	//check the service request for receiver
	check_lp_request(1);

	//enable LEN bit of link port receiver
	enable_lpDMA(1);
}

/**************************************************************************************************************************
	Function name	:   EPPI_init
    Description		:   This function initializes the EPPI Port
**************************************************************************************************************************/
void EPPI_init(unsigned int uiEppiID, unsigned int uiBytes)
{
	EPPI_Pin_Config(uiEppiID, 1, DATAWIDTH);									// Configure the pin multiplexing registers
	EPPI_Control_Config(uiEppiID, EPPI_CTL, EPPI_CTL2, 1);						// Configure EPPI control, control2 and clock divisor registers respectively.
	EPPI_Line_Config(uiEppiID, uiBytes, uiBytes, 0);							// Configure EPPI Line, Hcount and Hdelay registers respectively.
	EPPI_FSync_Config(uiEppiID, 3, uiBytes, 0 , 0 );							// Configure EPPI FS1-width, FS1-period, FS2-width and FS2-period registers respectively.
	EPPI_IMASK_Config(uiEppiID, 0);												// Configure EPPI IMASK register.
}

/**************************************************************************************************************************
	Function name	:   EPPI_init1
    Description		:   This function initializes the EPPI Port
**************************************************************************************************************************/
void EPPI_init1(unsigned int uiEppiID, unsigned int uiBytes)
{
	EPPI_Pin_Config(uiEppiID, 1, DATAWIDTH1);									// Configure the pin multiplexing registers
	EPPI_Control_Config(uiEppiID, EPPI2_CTL, EPPI_CTL2, 1);						// Configure EPPI control, control2 and clock divisor registers respectively.
	EPPI_Line_Config(uiEppiID, uiBytes, uiBytes, 0);							// Configure EPPI Line, Hcount and Hdelay registers respectively.
	EPPI_FSync_Config(uiEppiID, 3, uiBytes, 0 , 0 );							// Configure EPPI FS1-width, FS1-period, FS2-width and FS2-period registers respectively.
	EPPI_IMASK_Config(uiEppiID, 0);												// Configure EPPI IMASK register.
}

/**************************************************************************************************************************
	Function name	:   EPPI0_Interrupt_Handler
    Description		:   Interrupt handler for EPPI0
**************************************************************************************************************************/
void EPPI0_Interrupt_Handler (uint32_t iid, void* handlerArg)
{
	clock_stop_ppi0 = clock();
	*pREG_DMA29_STAT |= ENUM_DMA_STAT_IRQDONE;			 //Clear the W1C interrupt status bit
	DMA_Done_PPI0 = 1;                              	//Flag to indicate that PPI0 DMA has finished
}

/**************************************************************************************************************************
	Function name	:   EPPI1_Interrupt_Handler
    Description		:   Interrupt handler for EPPI1
**************************************************************************************************************************/
void EPPI1_Interrupt_Handler (uint32_t iid, void* handlerArg)
{
	clock_stop_ppi1 = clock();
	*pREG_DMA33_STAT |= ENUM_DMA_STAT_IRQDONE;			 //Clear the W1C interrupt status bit
	DMA_Done_PPI1 = 1;                              	//Flag to indicate that PPI1 DMA has finished
}

/**************************************************************************************************************************
	Function name	:   EPPI2_Interrupt_Handler
    Description		:   Interrupt handler for EPPI2
**************************************************************************************************************************/
void EPPI2_Interrupt_Handler (uint32_t iid, void* handlerArg)
{
	clock_stop_ppi2 = clock();
	*pREG_DMA31_STAT |= ENUM_DMA_STAT_IRQDONE;			 //Clear the W1C interrupt status bit
	DMA_Done_PPI2 = 1;                              	 //Flag to indicate that PPI2 DMA has finished
}

/**************************************************************************************************************************
	Function name	:   MDMA_Interrupt_Handler
    Description		:   Interrupt handler for MDMA stream
**************************************************************************************************************************/
void MDMA_Interrupt_Handler(uint32_t iid, void* handlerArg)
{
	clock_stop_mdma = clock();
	*pREG_DMA22_STAT |= ENUM_DMA_STAT_IRQDONE;			 //Clear the W1C interrupt status bit
	DMA_Done_MDMA = 1;									 //Flag to indicate that MDMA has finished
}

/**************************************************************************************************************************
	Function name	:   LP0_RX_Handler
    Description		:   Interrupt handler for Link Port
**************************************************************************************************************************/
void LP0_RX_Handler (uint32_t iid, void* handlerArg)
{
	clock_stop_lp = clock();
	*pREG_DMA13_STAT |= BITM_DMA_STAT_IRQDONE; 		//clear rqst
	DMA_Done_LP = 1;								//Flag to indicate that Link port DMA has finished
}
