/*****************************************************************************
 * MDMA_Throughput_Measurements_Core0.c
 *****************************************************************************/

/*This code can be used to perform read and write throughput measurements for MDMA
 * under various conditions: sequential, non-sequential, different MSIZE values,
 * different DDR settings etc.
 *
 *
 */

#include <ccblkfn.h>
#include "adi_initialize.h"
#include "MDMA_Throughput_Measurements_Core0.h"
#include <cdefBF609.h>
#include <defBF609.h>
#include "ddr_init.h"
#include "time.h"
#include "stdio.h"

volatile clock_t clock_start;
volatile clock_t clock_stop;
volatile clock_t cycles;
volatile clock_t overhead;
volatile clock_t actual_cycles;

float throughput;

extern void DDR2_Init(void);

#pragma align 32
section("L1_data_a") unsigned char ucIntSrcBuff[1];

#pragma align 32
section("L1_data_b") unsigned char ucIntDestBuff[MAX_SIZE];

#pragma align 32
section("sdram0_bank0") unsigned char ucExtSrcBuff[MAX_SIZE];
//section("l2_sram") unsigned char ucExtSrcBuff[MAX_SIZE];
//section("L1_data_a") unsigned char ucExtSrcBuff[MAX_SIZE];

#pragma align 32
section("sdram0_bank0") unsigned char ucExtDestBuff[MAX_SIZE];


void Measure_Throughput_Read_MDMA(unsigned int uiBytes, unsigned int uiSourceDMAConfig, unsigned int uiDestDMAConfig);
void Measure_Throughput_Write_MDMA(unsigned int uiBytes, unsigned int uiSourceDMAConfig, unsigned int uiDestDMAConfig);
void Fill_Buff(unsigned char* ucpBuff, unsigned int uiCount);

#define MDMA_CONFIG(S_MDMA_CHANNEL,S_CFG, S_ADDRSTART, S_MOD, S_COUNT,D_MDMA_CHANNEL,D_CFG, D_ADDRSTART, D_MOD, D_COUNT)\
		*pREG_DMA##S_MDMA_CHANNEL##_CFG = S_CFG;\
		*pREG_DMA##S_MDMA_CHANNEL##_ADDRSTART = S_ADDRSTART;\
		*pREG_DMA##S_MDMA_CHANNEL##_XCNT = S_COUNT;\
		*pREG_DMA##S_MDMA_CHANNEL##_XMOD = S_MOD;\
		*pREG_DMA##D_MDMA_CHANNEL##_CFG = D_CFG;\
		*pREG_DMA##D_MDMA_CHANNEL##_ADDRSTART = D_ADDRSTART;\
		*pREG_DMA##D_MDMA_CHANNEL##_XCNT = D_COUNT;\
		*pREG_DMA##D_MDMA_CHANNEL##_XMOD = D_MOD;\
		*pREG_DMA##S_MDMA_CHANNEL##_CFG |= 0x1;\
		*pREG_DMA##D_MDMA_CHANNEL##_CFG |= 0x1;\

#define WAIT_FOR_DMADONE(DMA_CHANNEL)\
		while(!(*pREG_DMA##DMA_CHANNEL##_STAT & ENUM_DMA_STAT_IRQDONE));

#define DISABLE_DMAs(S_MDMA_CHANNEL, D_MDMA_CHANNEL)\
		*pREG_DMA##S_MDMA_CHANNEL##_CFG = 0;\
		*pREG_DMA##D_MDMA_CHANNEL##_CFG = 0;



int main(void)
{
	unsigned int uiBytes=0;

	//Initialize DMC
	DDR2_Init();

	//Measure Read/Write throughput for different number of bytes (32, 64, 128...16384)
	for(uiBytes=32;uiBytes<=MAX_SIZE;uiBytes=uiBytes*2)
	{
		Fill_Buff(ucExtSrcBuff, uiBytes);
		Measure_Throughput_Read_MDMA(uiBytes, SOURCE_DMA_CFG, DEST_DMA_CFG);
	}

	return 0;
}

void Fill_Buff(unsigned char* ucpBuff, unsigned int uiCount)
{
	int i=0;

	for(i=0;i<uiCount;i++)
		*ucpBuff++=i;

}
void Measure_Throughput_Read_MDMA(unsigned int uiBytes, unsigned int uiSourceDMAConfig, unsigned int uiDestDMAConfig)
{


	//Configure MDMA to read from external memory
	MDMA_CONFIG(23, uiSourceDMAConfig, ucExtSrcBuff, SOURCE_MSIZE, uiBytes/SOURCE_MSIZE,24,uiDestDMAConfig, ucIntDestBuff, DEST_MSIZE, uiBytes/DEST_MSIZE);

	//Start cycle counter
	clock_start = clock();

	//Wait for the DMA done
	WAIT_FOR_DMADONE(24);

	//Stop cycle count
	clock_stop = clock();

	//Calculate no of CCLK cycles
	cycles=clock_stop-clock_start;


	//Remove the DMA polling overhead and get actual no of cycles.
	clock_start = clock();
	WAIT_FOR_DMADONE(24);
	clock_stop = clock();
	overhead=clock_stop-clock_start;
	actual_cycles=cycles-overhead;

	//Disable the DMAs
	DISABLE_DMAs(23,24);

	//Calculate the throughput and print the same
	throughput=(float)(uiBytes*CCLK_SPEED/actual_cycles);
	printf("\n\n No of bytes=%d, No of cycles=%d, ",uiBytes,actual_cycles,throughput);
	printf("Throughput=%f MB/s\n\n",throughput);

}

void Measure_Throughput_Write_MDMA(unsigned int uiBytes, unsigned int uiSourceDMAConfig, unsigned int uiDestDMAConfig)
{

	//Configure MDMA to write to external memory
	MDMA_CONFIG(21, uiSourceDMAConfig, ucIntSrcBuff, SOURCE_MSIZE, uiBytes/SOURCE_MSIZE,22,uiDestDMAConfig, ucExtDestBuff, 64*DEST_MSIZE, uiBytes/DEST_MSIZE);

	//Start cycle count
	clock_start = clock();

	//Wait for the DMA done
	WAIT_FOR_DMADONE(22);

	//Stop cycle count
	clock_stop = clock();

	//Calculate no of cycles
	cycles=clock_stop-clock_start;

	//Reduce the DMA polling overhead and get actual no of cycles
	clock_start = clock();
	WAIT_FOR_DMADONE(22);
	clock_stop = clock();
	overhead=clock_stop-clock_start;
	actual_cycles=cycles-overhead;

	//Disable the DMAs
	DISABLE_DMAs(21,22);

	//Calculate and print throughput values
	throughput=(float)(uiBytes*CCLK_SPEED/actual_cycles);
	printf("\n\n No of bytes=%d, No of cycles=%d, ",uiBytes,actual_cycles,throughput);
	printf("Throughput=%f MB/s\n\n",throughput);

}


