/*The example code involves the following conditions.
	CCLK=500 MHz, SYSCLK = 250 MHz, SCLK0 = SCLK1=125 MHz
	SCB5
		o	 PPI0 running in 24 bit transmit, internal clock and frame sync mode at PPICLK=62.5 MHz. This requires a throughput = 62.5*3 = 187.5 MB/s.
		o	PPI2 running in 16 bit transmit, internal clock and frame sync mode at PPICLK=62.5 MHz. This requires a throughput = 62.5*2 = 125 MB/s.
		o	The total throughput requirement by SCB5 from SCB0(MI0) = 187.5 + 125 = 312.5 MB/s
	SCB6
		o	PPI1 running in 16 bit transmit, and internal clock and frame sync mode at PPICLK=62.5 MHz.
		o	The total throughput requirement by SCB6 from SCB0(MI0) = 52.5*2 = 125 MB/s.
	SCB3
		o	Link Port 1 (LP1) and Link Port 0 (LP0) running in loopback with LP1 as transmitter and LP0 as receiver with LPCLK = 62.5 MHz.
		o	The total throughput requirement by SCB6 from SCB0(MI0) = 62.5 MB/s
	SCB4
	o	MDMA0 channels (21-22) and MDMA1 channels (25-26).
	o	The throughput requirements for these channels depend upon the corresponding DMAx_BWLCNT register values. If they are not programmed, the MDMA channels request for the bandwidth with full throttle (every SCLK cycle). This means that both the MDMA channels request to SCB4 for an individual throughput of 125*4 = 500 MB/s.
	o	However, since SCB4 runs on SCLK itself, the maximum total theoretical bandwidth request by SCB4 from SCB0-MI0 is limited to 125*4 = 500 MB/s.

The code can be run under different conditions by commenting/uncommenting the corresponding conditions/optimization techniques in the

"Stress_Test_Core01.h" file.
*/
#include <ccblkfn.h>
#include "adi_initialize.h"
#include "Stress_Test_Core0.h"
#include <cdefBF609.h>
#include <defBF609.h>
#include "ddr_init.h"
#include "time.h"
#include "stdio.h"
#include "EPPIInit.h"

volatile clock_t clock_start_mdma0;
volatile clock_t clock_stop_mdma0;
volatile clock_t cycles_mdma0;
volatile clock_t cycles_mdma0_pre;
float throughput_mdma0=0;

volatile clock_t clock_start_mdma2;
volatile clock_t clock_stop_mdma2;
volatile clock_t cycles_mdma2;
volatile clock_t cycles_mdma2_pre;
float throughput_mdma2=0;

volatile clock_t clock_start_ppi0;
volatile clock_t clock_stop_ppi0;
volatile clock_t cycles_ppi0;
volatile clock_t cycles_ppi0_pre;
float throughput_ppi0=0;

volatile clock_t clock_start_ppi1;
volatile clock_t clock_stop_ppi1;
volatile clock_t cycles_ppi1;
volatile clock_t cycles_ppi1_pre;
float throughput_ppi1=0;

volatile clock_t clock_start_ppi2;
volatile clock_t clock_stop_ppi2;
volatile clock_t cycles_ppi2;
volatile clock_t cycles_ppi2_pre;
float throughput_ppi2=0;

volatile clock_t clock_start_lp0;
volatile clock_t clock_stop_lp0;
volatile clock_t cycles_lp0;
volatile clock_t cycles_lp0_pre;
float throughput_lp0=0;

float throughput_total=0;

extern void DDR2_Init(void);

#pragma align 32
section("L1_data_a") unsigned char ucIntSrcBuff[MAX_SIZE];
section("L1_data_a") unsigned char ucIntDest1Buff[MAX_SIZE];

#pragma align 32
section("L1_data_b") unsigned char ucIntDestBuff[MAX_SIZE];
section("L1_data_b") unsigned char ucIntSrc1Buff[MAX_SIZE];


#pragma align 32
section("sdram0_bank0") unsigned char ucExtSrcBuff[MAX_SIZE];

#pragma align 32
section("sdram0_bank0") unsigned char ucExtDestBuff[MAX_SIZE];


void Fill_Buff(unsigned char* ucpBuff, unsigned int uiCount);
void EPPI_init(unsigned int uiEppiID, unsigned int uiBytes, unsigned int EPPI_CTL_CFG, unsigned int EPPI_CTL2_CFG);
void EPPI0_Interrupt_Handler (uint32_t iid, void* handlerArg);
void MDMA0_Interrupt_Handler(uint32_t iid, void* handlerArg);
void MDMA2_Interrupt_Handler(uint32_t iid, void* handlerArg);
void LP0_RX_Handler (uint32_t iid, void* handlerArg);

extern void enable_lp_gpio(void);
extern void enable_lp_ezkit(void );
extern void program_lpDMA(int lpdir);
extern void program_lp_clk(int lpdir);
extern void check_lp_request(int lpdir);
extern void enable_lp_ezkit(void);


int DMA_Count_PPI0=0;
int DMA_Count_PPI1=0;
int DMA_Count_PPI2=0;
int DMA_Count_MDMA0=0;
int DMA_Count_MDMA2=0;
int DMA_Count_LP0=0;

int Error_Count_PPI0=0;
int Error_Count_PPI1=0;
int Error_Count_PPI2=0;

int Read_Arbitration;
int Write_Arbitration;
int slot;
int slave_id;
int scb_id;
int master_id;


//Macro to configure MDMA
#define MDMA_CONFIG(S_MDMA_CHANNEL,S_CFG, S_ADDRSTART, S_MOD, S_COUNT,D_MDMA_CHANNEL,D_CFG, D_ADDRSTART, D_MOD, D_COUNT)\
		*pREG_DMA##S_MDMA_CHANNEL##_CFG = S_CFG;\
		*pREG_DMA##S_MDMA_CHANNEL##_ADDRSTART = S_ADDRSTART;\
		*pREG_DMA##S_MDMA_CHANNEL##_XCNT = S_COUNT;\
		*pREG_DMA##S_MDMA_CHANNEL##_XMOD = S_MOD;\
		*pREG_DMA##D_MDMA_CHANNEL##_CFG = D_CFG;\
		*pREG_DMA##D_MDMA_CHANNEL##_ADDRSTART = D_ADDRSTART;\
		*pREG_DMA##D_MDMA_CHANNEL##_XCNT = D_COUNT;\
		*pREG_DMA##D_MDMA_CHANNEL##_XMOD = D_MOD;\
		*pREG_DMA##D_MDMA_CHANNEL##_CFG|= 0x1;\
		*pREG_DMA##S_MDMA_CHANNEL##_CFG|= 0x1;

//Macro to disable the MDMAs
#define DISABLE_MDMAs(S_MDMA_CHANNEL, D_MDMA_CHANNEL)\
		*pREG_DMA##S_MDMA_CHANNEL##_CFG = 0;\
		*pREG_DMA##D_MDMA_CHANNEL##_CFG = 0;

//Macro to disable PPIDMA
#define DISABLE_PPI_DMA(DMA_CHANNEL)\
		*pREG_DMA##DMA_CHANNEL##_CFG = 0;

//Macro to enable peripheral DMA
#define PDMA_CONFIG(PDMA_CHANNEL,S_CFG, S_ADDRSTART, S_MOD, S_COUNT)\
		*pREG_DMA##PDMA_CHANNEL##_CFG = S_CFG;\
		*pREG_DMA##PDMA_CHANNEL##_ADDRSTART = S_ADDRSTART;\
		*pREG_DMA##PDMA_CHANNEL##_XCNT = S_COUNT;\
		*pREG_DMA##PDMA_CHANNEL##_XMOD = S_MOD;\
		*pREG_DMA##PDMA_CHANNEL##_CFG|= 0x1;

//Macro to read the SCB read channel arbitration settings
#define READ_SCB_READ_ARBITRATION(SCB_ID, MASTER_ID, SLOT_NO)\
		*pREG_SCB##SCB_ID##_ARBR##MASTER_ID=0x##FF##0000##SLOT_NO;\
		Read_Arbitration=*pREG_SCB##SCB_ID##_ARBR##MASTER_ID;

//Macro to read the SCB write channel arbitration settings
#define READ_SCB_WRITE_ARBITRATION(SCB_ID, MASTER_ID, SLOT_NO)\
		*pREG_SCB##SCB_ID##_ARBW##MASTER_ID=0x##FF##0000##SLOT_NO;\
		Write_Arbitration=*pREG_SCB##SCB_ID##_ARBW##MASTER_ID;

//Macro to write the SCB read channel arbitration settings
#define WRITE_SCB_READ_ARBITRATION(SCB_ID, MASTER_ID, SLOT_NO, SLAVE_ID)\
		*pREG_SCB##SCB_ID##_ARBR##MASTER_ID=0x##SLOT_NO##0000##SLAVE_ID;\
		Read_Arbitration=*pREG_SCB##SCB_ID##_ARBR##MASTER_ID;

//Macro to write the SCB write channel arbitration settings
#define WRITE_SCB_WRITE_ARBITRATION(SCB_ID, MASTER_ID, SLOT_NO, SLAVE_ID)\
		*pREG_SCB##SCB_ID##_ARBW##MASTER_ID=0x##SLOT_NO##0000##SLAVE_ID;\
		Write_Arbitration=*pREG_SCB##SCB_ID##_ARBW##MASTER_ID;


int main(void)
{
	unsigned int uiBytes=0;

	//Initialize the DMC
	DDR2_Init();

	//Enable the interrupts globally
	*pREG_SEC0_GCTL=ENUM_SEC_GCTL_EN;
	*pREG_SEC0_CCTL0=ENUM_SEC_CCTL_EN;

	//Work unit size = 4 pages = 8K words
	uiBytes=2048*4;//8192;//6384; //16 K words

	unsigned int varSI;

	//Program the SCB parameters here
	#ifdef SCB_OPTIMIZATION


	//SCB0-MI0 programming

		//SCB5-SI5-PPI0, PPI2 - total 12 slots
		WRITE_SCB_READ_ARBITRATION(0, 0, 00, 05);
		WRITE_SCB_READ_ARBITRATION(0, 0, 01, 05);
		WRITE_SCB_READ_ARBITRATION(0, 0, 02, 05);
		WRITE_SCB_READ_ARBITRATION(0, 0, 03, 05);
		WRITE_SCB_READ_ARBITRATION(0, 0, 04, 05);
		WRITE_SCB_READ_ARBITRATION(0, 0, 05, 05);
		WRITE_SCB_READ_ARBITRATION(0, 0, 06, 05);
		WRITE_SCB_READ_ARBITRATION(0, 0, 07, 05);
		WRITE_SCB_READ_ARBITRATION(0, 0, 08, 05);
		WRITE_SCB_READ_ARBITRATION(0, 0, 09, 05);
		WRITE_SCB_READ_ARBITRATION(0, 0, 0A, 05);
		WRITE_SCB_READ_ARBITRATION(0, 0, 0B, 05);

		//SCB6-SI6-PPI1, total 5 slots
		WRITE_SCB_READ_ARBITRATION(0, 0, 0C, 06);
		WRITE_SCB_READ_ARBITRATION(0, 0, 0D, 06);
		WRITE_SCB_READ_ARBITRATION(0, 0, 0E, 06);
		WRITE_SCB_READ_ARBITRATION(0, 0, 0F, 06);
		WRITE_SCB_READ_ARBITRATION(0, 0, 10, 06);

		//SCB3-SI11-LP1, total 2 slots
		WRITE_SCB_READ_ARBITRATION(0, 0, 11, 0B);
		WRITE_SCB_READ_ARBITRATION(0, 0, 12, 0B);

		//SCB4-SI12-MDMA, total 13 slots
		WRITE_SCB_READ_ARBITRATION(0, 0, 13, 0C);
		WRITE_SCB_READ_ARBITRATION(0, 0, 14, 0C);
		WRITE_SCB_READ_ARBITRATION(0, 0, 15, 0C);
		WRITE_SCB_READ_ARBITRATION(0, 0, 16, 0C);
		WRITE_SCB_READ_ARBITRATION(0, 0, 17, 0C);
		WRITE_SCB_READ_ARBITRATION(0, 0, 18, 0C);
		WRITE_SCB_READ_ARBITRATION(0, 0, 19, 0C);
		WRITE_SCB_READ_ARBITRATION(0, 0, 1A, 0C);
		WRITE_SCB_READ_ARBITRATION(0, 0, 1B, 0C);
		WRITE_SCB_READ_ARBITRATION(0, 0, 1C, 0C);
		WRITE_SCB_READ_ARBITRATION(0, 0, 1D, 0C);
		WRITE_SCB_READ_ARBITRATION(0, 0, 1E, 0C);
		WRITE_SCB_READ_ARBITRATION(0, 0, 1F, 0C);

	//SCB4-MI0 programming
		WRITE_SCB_READ_ARBITRATION(4, 0, 00, 00);
		WRITE_SCB_READ_ARBITRATION(4, 0, 01, 00);
		WRITE_SCB_READ_ARBITRATION(4, 0, 02, 00);
		WRITE_SCB_READ_ARBITRATION(4, 0, 03, 00);
		WRITE_SCB_READ_ARBITRATION(4, 0, 04, 00);
		WRITE_SCB_READ_ARBITRATION(4, 0, 05, 00);
		WRITE_SCB_READ_ARBITRATION(4, 0, 06, 00);
		WRITE_SCB_READ_ARBITRATION(4, 0, 07, 00);

		WRITE_SCB_READ_ARBITRATION(4, 0, 08, 04);
		WRITE_SCB_READ_ARBITRATION(4, 0, 09, 04);
		WRITE_SCB_READ_ARBITRATION(4, 0, 0A, 04);
		WRITE_SCB_READ_ARBITRATION(4, 0, 0B, 04);
		WRITE_SCB_READ_ARBITRATION(4, 0, 0C, 04);
		WRITE_SCB_READ_ARBITRATION(4, 0, 0D, 04);
		WRITE_SCB_READ_ARBITRATION(4, 0, 0E, 04);
		WRITE_SCB_READ_ARBITRATION(4, 0, 0F, 04);

	#endif

	int i;


	//Enables PPI0 DMA
	#ifdef ENABLE_PPI0_DMA_187_5MBPS
		adi_int_InstallHandler(INTR_EPPI0_CH0_DMA, EPPI0_Interrupt_Handler, NULL, true);
		PDMA_CONFIG(29,PPI0_DMA_CFG, PPI0_DMA_DMC_START_ADDRESS, PPI0_MSIZE, uiBytes/PPI0_MSIZE);
		for(i=0;i<1000;i++);
		EPPI_init(0,uiBytes,EPPI0_CTL_CFG, EPPI0_CTL2_CFG );
	#endif

	//Enables PPI1 DMA
	#ifdef ENABLE_PPI1_DMA_125MBPS
		adi_int_InstallHandler(INTR_EPPI1_CH0_DMA, EPPI1_Interrupt_Handler, NULL, true);
		PDMA_CONFIG(33,PPI1_DMA_CFG, PPI1_DMA_DMC_START_ADDRESS, PPI1_MSIZE, uiBytes/PPI1_MSIZE);
		EPPI_init(1,uiBytes,EPPI1_CTL_CFG, EPPI1_CTL2_CFG );
	#endif

	//Enables PPI2 DMA
	#ifdef ENABLE_PPI2_DMA_125MBPS
		adi_int_InstallHandler(INTR_EPPI2_CH0_DMA, EPPI2_Interrupt_Handler, NULL, true);
		PDMA_CONFIG(31,PPI2_DMA_CFG, PPI2_DMA_DMC_START_ADDRESS, PPI2_MSIZE, uiBytes/PPI2_MSIZE);
		EPPI_init(2,uiBytes,EPPI2_CTL_CFG, EPPI2_CTL2_CFG );
	#endif

	//Enables MDMA0
	#ifdef ENABLE_MDMA0_DMA_500MBPS
		adi_int_InstallHandler(INTR_MDMA0_DST, MDMA0_Interrupt_Handler, NULL, true);
		#ifdef USE_L2_FOR_MDMA0
			MDMA_CONFIG(21, SOURCE_DMA_CFG_MDMA2 , MDMA0_DMA_L2_START_ADDRESS, SOURCE_MSIZE_MDMA2, uiBytes/SOURCE_MSIZE_MDMA2,22,DEST_DMA_CFG_MDMA2, ucIntDestBuff, DEST_MSIZE_MDMA0, uiBytes/DEST_MSIZE_MDMA2);
		#else
			MDMA_CONFIG(21, SOURCE_DMA_CFG_MDMA0 , MDMA0_DMA_DMC_START_ADDRESS, SOURCE_MSIZE_MDMA0, uiBytes/SOURCE_MSIZE_MDMA0,22,DEST_DMA_CFG_MDMA0, ucIntDestBuff, DEST_MSIZE_MDMA0, uiBytes/DEST_MSIZE_MDMA0);
		#endif

		#ifdef LIMIT_MDMA0_BW
			*pREG_DMA21_BWLCNT=SOURCE_MSIZE_MDMA0*SCLK_SPEED/LIMIT_MDMA0_BW;//2048;
		#endif

	#endif

	//Enables MDMA2
	#ifdef ENABLE_MDMA2_DMA_500MBPS
		adi_int_InstallHandler(INTR_MDMA2_DST, MDMA2_Interrupt_Handler, NULL, true);

		#ifdef USE_L2_FOR_MDMA2
			MDMA_CONFIG(25, SOURCE_DMA_CFG_MDMA2 , MDMA2_DMA_L2_START_ADDRESS, SOURCE_MSIZE_MDMA2, uiBytes/SOURCE_MSIZE_MDMA2,26,DEST_DMA_CFG_MDMA2, ucIntDestBuff, DEST_MSIZE_MDMA0, uiBytes/DEST_MSIZE_MDMA2);
		#else
			MDMA_CONFIG(25, SOURCE_DMA_CFG_MDMA2 , MDMA2_DMA_DMC_START_ADDRESS, SOURCE_MSIZE_MDMA2, uiBytes/SOURCE_MSIZE_MDMA2,26,DEST_DMA_CFG_MDMA2, ucIntDestBuff, DEST_MSIZE_MDMA0, uiBytes/DEST_MSIZE_MDMA2);
		#endif

		#ifdef LIMIT_MDMA2_BW
			*pREG_DMA25_BWLCNT=SOURCE_MSIZE_MDMA2*SCLK_SPEED/LIMIT_MDMA2_BW;//2048;
		#endif

	#endif

	//Enables LP1-LP0 DMA
	#ifdef ENABLE_LP0_LP1_DMA_62_5MBPS
		adi_int_InstallHandler(INTR_LP0_DMA,LP0_RX_Handler,0,true);
		Enable_Link_Port_DMA();
	#endif


	//Wait for all the DMAs to complete at least 500 times
	#ifdef ENABLE_PPI0_DMA_187_5MBPS
		while(DMA_Count_PPI0<500);
	#endif

	#ifdef ENABLE_PPI1_DMA_125MBPS
		while(DMA_Count_PPI1<500);
	#endif

	#ifdef ENABLE_PPI2_DMA_125MBPS
		while(DMA_Count_PPI2<500);
	#endif

	#ifdef ENABLE_MDMA0_DMA_500MBPS
		while(DMA_Count_MDMA0<500);
	#endif

	#ifdef ENABLE_MDMA2_DMA_500MBPS
		while(DMA_Count_MDMA2<500);
	#endif

	#ifdef ENABLE_LP0_LP1_DMA_62_5MBPS
		while(DMA_Count_LP0<500);
	#endif

	//Check for any PPI underflow errors
	if(*pREG_EPPI0_STAT&ENUM_EPPI_STAT_YFIFOERR)
			Error_Count_PPI0=1;

	if(*pREG_EPPI2_STAT&ENUM_EPPI_STAT_YFIFOERR)
				Error_Count_PPI2=1;

	if(*pREG_EPPI1_STAT&ENUM_EPPI_STAT_YFIFOERR)
			Error_Count_PPI1=1;

	//Disable the peripherals and MDMAs
	*pREG_EPPI0_CTL =0;
	*pREG_EPPI1_CTL =0;
	*pREG_EPPI2_CTL =0;
	DISABLE_MDMAs(21,22);
	DISABLE_MDMAs(25,26);
	*pREG_LP1_CTL=0;
	*pREG_LP0_CTL=0;
	*pREG_DMA14_CFG =0;
	*pREG_DMA13_CFG =0;

	//Print the throughput numbers

	#ifdef ENABLE_PPI0_DMA_187_5MBPS
		if(Error_Count_PPI0)
			printf("FIFO Underflow Error in PPI0 !!!\n\n");
		throughput_ppi0=(float)uiBytes*CCLK_SPEED/cycles_ppi0;
			printf("Throughput PPI0=%f MB/s\n\n", throughput_ppi0);
	#endif

	#ifdef ENABLE_PPI1_DMA_125MBPS
		if(Error_Count_PPI1)
			printf("FIFO Underflow Error in PPI1 !!!\n\n");
		throughput_ppi1=(float)uiBytes*CCLK_SPEED/cycles_ppi1;
		printf("Throughput PPI1=%f MB/s\n\n", throughput_ppi1);
	#endif

	#ifdef ENABLE_PPI2_DMA_125MBPS
		if(Error_Count_PPI2)
			printf("FIFO Underflow Error in PPI2 !!!\n\n");

		throughput_ppi2=(float)uiBytes*CCLK_SPEED/cycles_ppi2;
		printf("Throughput PPI2=%f MB/s\n\n", throughput_ppi2);
	#endif

	#ifdef ENABLE_MDMA0_DMA_500MBPS
		throughput_mdma0=(float)uiBytes*CCLK_SPEED/cycles_mdma0;
		printf("Throughput MDMA0=%f MB/s\n\n", throughput_mdma0);
	#endif

	#ifdef ENABLE_MDMA2_DMA_500MBPS
		throughput_mdma2=(float)uiBytes*CCLK_SPEED/cycles_mdma2;
		printf("Throughput MDMA2=%f MB/s\n\n", throughput_mdma2);
	#endif

	#ifdef ENABLE_LP0_LP1_DMA_62_5MBPS
		throughput_lp0=(float)uiBytes*CCLK_SPEED/cycles_lp0;
		printf("Throughput LP0_LP1=%f MB/s\n\n", throughput_lp0);
	#endif

	throughput_total = throughput_ppi0 +  throughput_ppi1 + throughput_ppi2 + throughput_mdma0 + throughput_mdma2 + throughput_lp0;

	printf("Throughput total=%f MB/s\n\n", throughput_total);

	return 0;
}

void Enable_Link_Port_DMA()
{
	//enable the right mux and fer for GPIO for both link ports, tx and rx
	enable_lp_gpio();

	//enable the lvds switch via IO expander through TWI
	enable_lp_ezkit();

	//enable interrupts. see condition above.
	//enable_interrupts();

	//program link port with transfer direction and interrupt masking
	program_lpDMA(0);

	//program link port with transfer direction and interrupt masking
	program_lpDMA(1);

	//program link port clock for transmitter
	program_lp_clk(1);

	//enable LEN bit of link port transmitter
	enable_lpDMA(0);

	//check the service request for receiver
	check_lp_request(1);

	//enable LEN bit of link port receiver
	enable_lpDMA(1);

}
void Fill_Buff(unsigned char* ucpBuff, unsigned int uiCount)
{
	int i=0;

	for(i=0;i<uiCount;i++)
		*ucpBuff++=i;

}



void EPPI_init(unsigned int uiEppiID, unsigned int uiBytes, unsigned int EPPI_CTL_CFG, unsigned int EPPI_CTL2_CFG)
{
	EPPI_Pin_Config(uiEppiID, 1, DATAWIDTH);									// Configure the pin multiplexing registers
	EPPI_Control_Config(uiEppiID, EPPI_CTL_CFG, EPPI_CTL2_CFG, 1);						// Configure EPPI control, control2 and clock divisor registers respectively.
	EPPI_Line_Config(uiEppiID, uiBytes, uiBytes, 0);								// Configure EPPI Line, Hcount and Hdelay registers respectively.
	EPPI_FSync_Config(uiEppiID, 3, uiBytes, 0 , 0 );								// Configure EPPI FS1-width, FS1-period, FS2-width and FS2-period registers respectively.
	EPPI_IMASK_Config(uiEppiID, 0);												// Configure EPPI IMASK register.

}



void EPPI0_Interrupt_Handler (uint32_t iid, void* handlerArg)
{
	clock_start_ppi0=clock_stop_ppi0;
	clock_stop_ppi0 = clock();
	cycles_ppi0_pre=cycles_ppi0;
	cycles_ppi0=clock_stop_ppi0-clock_start_ppi0;
	if(DMA_Count_PPI0>0)
	{
		cycles_ppi0=(DMA_Count_PPI0*cycles_ppi0_pre+cycles_ppi0)/(DMA_Count_PPI0+1);
	}

	*pREG_DMA29_STAT |= ENUM_DMA_STAT_IRQDONE;			 //Clear the W1C interrupt status bit
	DMA_Count_PPI0++;
	if(DMA_Count_PPI0==1)
		*pREG_DMA29_STAT |= ENUM_EPPI_STAT_YFIFOERR;			 //Clear the W1C interrupt status bit

}


void EPPI1_Interrupt_Handler (uint32_t iid, void* handlerArg)
{
	clock_start_ppi1=clock_stop_ppi1;
	clock_stop_ppi1 = clock();
	cycles_ppi1_pre=cycles_ppi1;
	cycles_ppi1=clock_stop_ppi1-clock_start_ppi1;
	if(DMA_Count_PPI1>0)
	{
		cycles_ppi1=(DMA_Count_PPI1*cycles_ppi1_pre+cycles_ppi1)/(DMA_Count_PPI1+1);
	}
	*pREG_DMA33_STAT |= ENUM_DMA_STAT_IRQDONE;			 //Clear the W1C interrupt status bit
	DMA_Count_PPI1++;
}


void EPPI2_Interrupt_Handler (uint32_t iid, void* handlerArg)
{
	clock_start_ppi2=clock_stop_ppi2;
	clock_stop_ppi2 = clock();
	cycles_ppi2_pre=cycles_ppi2;
	cycles_ppi2=clock_stop_ppi2-clock_start_ppi2;
	if(DMA_Count_PPI2>0)
	{
		cycles_ppi2=(DMA_Count_PPI2*cycles_ppi2_pre+cycles_ppi2)/(DMA_Count_PPI2+1);
	}
	*pREG_DMA31_STAT |= ENUM_DMA_STAT_IRQDONE;			 //Clear the W1C interrupt status bit
	DMA_Count_PPI2++;
}




void MDMA0_Interrupt_Handler(uint32_t iid, void* handlerArg)
{
	clock_start_mdma0=clock_stop_mdma0;
	clock_stop_mdma0 = clock();
	cycles_mdma0_pre=cycles_mdma0;
	cycles_mdma0=clock_stop_mdma0-clock_start_mdma0;
	if(DMA_Count_MDMA0>0)
	{
		cycles_mdma0=(DMA_Count_MDMA0*cycles_mdma0_pre+cycles_mdma0)/(DMA_Count_MDMA0+1);
	}

	*pREG_DMA22_STAT |= ENUM_DMA_STAT_IRQDONE;			 //Clear the W1C interrupt status bit

	DMA_Count_MDMA0++;
}

void MDMA2_Interrupt_Handler(uint32_t iid, void* handlerArg)
{
	clock_start_mdma2=clock_stop_mdma2;
	clock_stop_mdma2= clock();
	cycles_mdma2_pre=cycles_mdma2;
	cycles_mdma2=clock_stop_mdma2-clock_start_mdma2;
	if(DMA_Count_MDMA2>0)
	{
		cycles_mdma2=(DMA_Count_MDMA2*cycles_mdma2_pre+cycles_mdma2)/(DMA_Count_MDMA2+1);
	}

	*pREG_DMA26_STAT |= ENUM_DMA_STAT_IRQDONE;			 //Clear the W1C interrupt status bit

	DMA_Count_MDMA2++;
}

void LP0_RX_Handler (uint32_t iid, void* handlerArg)
{
	clock_start_lp0=clock_stop_lp0;
	clock_stop_lp0= clock();
	cycles_lp0=clock_stop_lp0-clock_start_lp0;

	*pREG_DMA13_STAT |= BITM_DMA_STAT_IRQDONE; 		//clear rqst

	DMA_Count_LP0++;
}


