/*
 *  (C) Copyright 2012 - Analog Devices, Inc. All Rights Reserved.
 *
 * This software is proprietary and confidential.  By using this software
 * you agree to the terms of the associated Analog Devices License Agreement.
 *
 * Project Name:  	Power_On_Self_Test
 *
 * Hardware:		ADSP-BF609 EZ-Board
 * Description:	This examples performs a DDR Memory test on the EZ-Board.
 */
#include <cdefBF609.h>
#include <defBF609.h>
#include <ccblkfn.h>
//#include "post_common.h"
//#include "post_debug.h"
#include "cgu_init.h"
#include "ddr_init.h"
#include <math.h>

#define DLL_LOCK_PERIOD 4500


/* DDR2 timing parameters after calculation */
unsigned int uiCL=0, uiRCD=0, uiRP=0,uiRC=0, uiRRD=0, uiRAS=0, uiRFC=0, uiFAW=0, uiRTP=0, uiWR=0, uiWTR=0, uiREFVAL =0;

/* Local Function Declarations */
void DDR2_Config(unsigned int uiDDRCfg, unsigned int uiDDRTr0, unsigned int uiDDRTr1, unsigned int uiDDRTr2, unsigned int uiDDRMr, unsigned int uiDDREmr1, unsigned int uiDDRCtl);

/* Calculate DDR2 timing parameters based on DCLK */
int Calc_Params(  float uiDDR2Val,  float fDCLKns);


/*
 *	Function name:   DDR2_Init
 * 	Description:	 This function initializes the DDR2 based on CGU initialization.
 * 	Obtains the MSEL/CLKIN/DF values and calculates DCLK. Based on DCLK calculates
 * 	timing parameters
 *	Arguments:       None
 *	Return value:    None.
 */
void DDR2_Init(void)
{
	int i=0,Dll_cycles;
	int DFval=0, DSELval = 0, MSELval=0, CSELval = 0;

	/* Check for DMA IDLE */
	while(!(*pREG_DMC0_STAT & BITM_DMC_STAT_IDLE))
		NOP;

	/* put the part into self refresh only if already initialized */
	if((*pREG_DMC0_STAT & BITM_DMC_STAT_MEMINITDONE)&&(*pREG_DMC0_STAT & BITP_DMC_STAT_DLLCALDONE))
	{
		/* Enable self Refresh */
		*pREG_DMC0_CTL |= BITM_DMC_CTL_SRREQ;

		/* wait for SRACK to get set */
		while(!(*pREG_DMC0_STAT & BITM_DMC_STAT_SRACK))
			NOP;
	}
	/* CGU init */
	CGU_Init(20, 1, 2);

	/* calculate the DLL wait cycles */
	DSELval = (*pREG_CGU0_DIV & BITM_CGU_DIV_DSEL) >> BITP_CGU_DIV_DSEL;
	CSELval = (*pREG_CGU0_DIV & BITM_CGU_DIV_CSEL) >> BITP_CGU_DIV_CSEL;
	Dll_cycles =DLL_LOCK_PERIOD * DSELval/CSELval;

	/* DLL Lock */
	for (i=0; i<Dll_cycles; i++)
		NOP;

	/* Get the DDR2 out of self refresh only if already initialized */
	if((*pREG_DMC0_STAT & BITM_DMC_STAT_MEMINITDONE)&&(*pREG_DMC0_STAT & BITP_DMC_STAT_DLLCALDONE))
	{
		/* Disable self refresh */
		*pREG_DMC0_CTL ^=BITM_DMC_CTL_SRREQ;

		/* Wait for SRACK to clear */
		while((*pREG_DMC0_STAT & BITM_DMC_STAT_SRACK))
			NOP;
	}

	/* Get CGU information -  needs CLKIN, DSEL, DF, MSEL */
	DFval   = (*pREG_CGU0_CTL & BITM_CGU_CTL_DF) >> BITP_CGU_CTL_DF;
	MSELval = (*pREG_CGU0_CTL & BITM_CGU_CTL_MSEL) >> BITP_CGU_CTL_MSEL;

	/* Calculate DCLK */
	float fDCLKMHz = 0, fDCLKns =0;
	fDCLKMHz = ((CLKINMHz * MSELval)/(DFval+1))/(DSELval);
	fDCLKns = 1000/fDCLKMHz;


	/* Calculate parameters */
	if (fDCLKMHz >= 200 )
		uiCL = 4;
	else
		uiCL = 3;

	uiRCD =	 Calc_Params(DDR2_RCD,fDCLKns);
	uiRP  =  Calc_Params(DDR2_RP,fDCLKns);
	uiRC  =  Calc_Params(DDR2_RC,fDCLKns);
	uiRRD =  Calc_Params(DDR2_RRD,fDCLKns);
	uiRAS =  Calc_Params(DDR2_RAS,fDCLKns);
	uiRFC =  Calc_Params(DDR2_RFC,fDCLKns);
	uiFAW =  Calc_Params(DDR2_FAW,fDCLKns);
	uiWR  =  Calc_Params(DDR2_WR,fDCLKns);
	uiWTR =  Calc_Params(DDR2_WTR,fDCLKns);
    uiREFVAL = fDCLKMHz *DDR2_TREFIus;


    DDR2_Config(DDR0_CFG, DDR0_TR0, DDR0_TR1,DDR0_TR2, DDR0_MR, DDR0_EMR1,DDR0_CTL);

}

void DDR2_Config(unsigned int uiDDRCfg, unsigned int uiDDRTr0, unsigned int uiDDRTr1, unsigned int uiDDRTr2, unsigned int uiDDRMr, unsigned int uiDDREmr1, unsigned int uiDDRCtl)
{
	int i=0;
	int dllDataCycle;

	/* Configure DDR2 registers */
	*pREG_DMC0_CFG = uiDDRCfg;
	*pREG_DMC0_TR0 = uiDDRTr0;
	*pREG_DMC0_TR1 = uiDDRTr1;
	*pREG_DMC0_TR2=  uiDDRTr2;
	*pREG_DMC0_MR=   uiDDRMr;
	*pREG_DMC0_EMR1=   uiDDREmr1;
	*pREG_DMC0_PHY_CTL3 = BITM_DMC_PHY_CTL3_ENODTDQ|BITM_DMC_PHY_CTL3_TMG0|BITM_DMC_PHY_CTL3_TMG1|BITM_DMC_PHY_CTL3_OFST0|BITM_DMC_PHY_CTL3_OFST1;
	*pREG_DMC0_PHY_CTL1 =ENUM_DMC_PHY_CTL1_ODT_75;
//	*pREG_DMC0_EFFCTL=(8<<BITP_DMC_EFFCTL_NUMREF)|(15<<BITP_DMC_EFFCTL_IDLECYC);//xFF00;//(8<<BITP_DMC_EFFCTL_NUMREF)|(1<<BITP_DMC_EFFCTL_IDLECYC);//BITM_DMC_EFFCTL_PRECBANK1;
	*pREG_DMC0_CTL=  uiDDRCtl;
//	*pREG_DMC0_PRIO=0x0000000C;
	//*pREG_DMC0_PRIOMSK=0xFFFF;


	/* Wait for initialization to complete */
	while(!(*pREG_DMC0_STAT & BITM_DMC_STAT_MEMINITDONE))
		NOP;

	/* Wait for calibration to complete */
	while(!(*pREG_DMC0_STAT & BITP_DMC_STAT_DLLCALDONE))
		NOP;


	/* keep the DLLCALRDCNT reset value and only modify DATACYC */
	*pREG_DMC0_DLLCTL= 0x54B;

}

/*
 *	Function name:   CalcParams
 * 	Description:	 This function calculates DDR2 timing parameters based on DCLK
 *	Arguments:       None
 *	Return value:    Returns the calculated parameter value
 */
int Calc_Params(  float uiDDR2Val,  float fDCLKns)
{
	int uiParamVal=0;
	float fParamVal = 0.0;

	fParamVal =uiDDR2Val/fDCLKns;
	uiParamVal = ceil(fParamVal);

	 return uiParamVal;
}
